use anyhow::Result;
use serde;
use tide::http::mime;
use tide::prelude::*;
use tide::Request;
use tide::Response;

use crate::config::Config;
use crate::vault::VaultRef;

#[derive(Clone)]
pub struct Interface {
    vault: VaultRef,
    config: Config,
}

pub async fn serve(vault: VaultRef, config: Config) -> Result<()> {
    let mut app = tide::with_state(Interface { vault, config });
    app.at("/").get(overview);
    app.at("/styles.css").get(styles);
    app.listen("127.0.0.1:8000").await?;
    Ok(())
}

async fn overview(req: Request<Interface>) -> tide::Result {
    let r = Response::builder(200)
        .content_type(mime::HTML)
        .body(format!(
            include_str!("../../data/www/admin.html"),
            TITLE = "Wooly-Vault"
        ));

    Ok(r.into())
}

async fn styles(_req: Request<Interface>) -> tide::Result {
    let r = Response::builder(200)
        .content_type(mime::CSS)
        .body(include_str!("../../data/www/styles.css"));
    Ok(r.into())
}
